;Filename: CmpMod.s79
;Part: ADuC702x.
;Created: 22/11/2004
;Updated: 28/06/2005
;Author: Barry Broderick.
;This file is in beta sampling.

#include        <ADuC702x.IAR.equ>
; CmpMod==========Sets the mode of the Comparator.
; C Function prototype: int CmpMod(int iPin, int iOut, int iRes);
;iPin:{CmpAdc3In,CmpDac0In}
;iOut:{CmpStAdcConv,CmpOut,CmpIrq}
;iRes:{Cmp10us,Cmp5us,Cmp1us,Cmp500ns}
; Description of Function: Configures necessary parts of the comparator.
; User Interface:
;  Set iPin to select the negative input:
;     CmpAdc3In   :  ADC3 input(default)
;     CmpDac0In   :  DAC0 input
;  Set iOut to select the output configuration bits:
;     CmpStAdcConv:  Start ADC conversion
;     CmpOut       : Output on CMPOut
;     CmpIrq       : IRQ
;  Set iRes to select the response time:
;     Cmp10us      : 10us
;     Cmp5us       :  5us
;     Cmp1us       :  1us
;     Cmp500ns    :  0.5us
;  Call CmpMod.
;  Returns 1.
; Robustness:
;  
; Side effects:
;  Corrupts r0 and r1

                RSEG CODE
                MODULE CmpMod
                PUBLIC CmpMod
                CODE32

CmpMod:  mov r0,r0,LSL#8         ;Left shift r0 by 8 bits
         orr   r0,r0,r1,LSL#6    ;Left shift r1 by 6 bits, Or with r0
         orr   r0,r0,r2,LSL#3    ;Left shift r2 by 6 bits, Or with r0

         mov   r3,#0xff0000      ;r3 = Z_BASE;
         orr   r3,r3,#0xff000000

         ldr   r1,[r3,#Z_CMPCON] ;Read CMPCON
   
         mov   r2,#0x27          ;Setup C27 in r2
         orr   r2,r2,#0xC00
   
         and   r1,r1,r2          ;erase the bits required to be changed
         orr   r0,r0,r1          ;Or r0 with r1
         str   r0,[r3,#Z_CMPCON] ;Write to CMPCON
   
         mov   r0,#0x01          ;Return 1
         bx    lr


                 ENDMOD CmpMod 

                 END
        
